@@ -13,7 +13,6 @@ from gen3.utils import (
     append_query_params,
     DEFAULT_BACKOFF_SETTINGS,
     BACKOFF_NO_LOG_IF_NOT_RETRIED,
-    raise_for_status_and_print_error,
     _verify_schema,
 )
 from gen3.auth import Gen3Auth
@@ -120,7 +119,7 @@ class Gen3Metadata:
             response = requests.get(
                 self.endpoint + "/_status", auth=self._auth_provider
             )
-            raise_for_status_and_print_error(response)
+            response.raise_for_status()
         except Exception as exc:
             logging.error(exc)
             return False
@@ -136,7 +135,7 @@ class Gen3Metadata:
             str: the version
         """
         response = requests.get(self.endpoint + "/version", auth=self._auth_provider)
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
         return response.text
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
@@ -150,7 +149,7 @@ class Gen3Metadata:
         response = requests.get(
             self.admin_endpoint + "/metadata_index", auth=self._auth_provider
         )
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
         return response.json()
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
@@ -164,7 +163,7 @@ class Gen3Metadata:
         response = requests.post(
             self.admin_endpoint + f"/metadata_index/{path}", auth=self._auth_provider
         )
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
         return response.json()
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
@@ -178,7 +177,7 @@ class Gen3Metadata:
         response = requests.delete(
             self.admin_endpoint + f"/metadata_index/{path}", auth=self._auth_provider
         )
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
         return response
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
@@ -244,11 +243,11 @@ class Gen3Metadata:
         )
         logging.debug(f"hitting: {url_with_params}")
         response = requests.get(url_with_params, auth=self._auth_provider)
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
 
         return response.json()
 
-    @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
+    @backoff.on_exception(backoff.expo, Exception, **BACKOFF_NO_LOG_IF_NOT_RETRIED)
     async def async_get(self, guid, _ssl=None, **kwargs):
         """
         Asynchronous function to get metadata
@@ -267,7 +266,7 @@ class Gen3Metadata:
             logging.debug(f"hitting: {url_with_params}")
 
             async with session.get(url_with_params, ssl=_ssl) as response:
-                raise_for_status_and_print_error(response)
+                response.raise_for_status()
                 response = await response.json()
 
         return response
@@ -319,7 +318,7 @@ class Gen3Metadata:
         response = requests.post(
             url_with_params, json=metadata_list, auth=self._auth_provider
         )
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
 
         return response.json()
 
@@ -342,7 +341,7 @@ class Gen3Metadata:
         response = requests.post(
             url_with_params, json=metadata, auth=self._auth_provider
         )
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
 
         return response.json()
 
@@ -351,6 +350,7 @@ class Gen3Metadata:
         self,
         guid,
         metadata,
+        aliases=None,
         overwrite=False,
         _ssl=None,
         **kwargs,
@@ -365,6 +365,8 @@ class Gen3Metadata:
             overwrite (bool, optional): whether or not to overwrite existing data
             _ssl (None, optional): whether or not to use ssl
         """
+        aliases = aliases or []
+        # todo handle aliases
         async with aiohttp.ClientSession() as session:
             url = self.admin_endpoint + f"/metadata/{guid}"
             url_with_params = append_query_params(url, overwrite=overwrite, **kwargs)
@@ -378,7 +380,7 @@ class Gen3Metadata:
             async with session.post(
                 url_with_params, json=metadata, headers=headers, ssl=_ssl
             ) as response:
-                raise_for_status_and_print_error(response)
+                response.raise_for_status()
                 response = await response.json()
 
         return response
@@ -401,12 +403,14 @@ class Gen3Metadata:
         response = requests.put(
             url_with_params, json=metadata, auth=self._auth_provider
         )
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
 
         return response.json()
 
     @backoff.on_exception(backoff.expo, Exception, **DEFAULT_BACKOFF_SETTINGS)
-    async def async_update(self, guid, metadata, _ssl=None, **kwargs):
+    async def async_update(
+        self, guid, metadata, aliases=None, merge=False, _ssl=None, **kwargs
+    ):
         """
         Asynchronous function to update metadata
 
@@ -416,8 +420,11 @@ class Gen3Metadata:
                 attached to the provided GUID as metadata
             _ssl (None, optional): whether or not to use ssl
         """
+        # TODO handle aliases
         async with aiohttp.ClientSession() as session:
             url = self.admin_endpoint + f"/metadata/{guid}"
+            if merge:
+                url += "?merge=True"
             url_with_params = append_query_params(url, **kwargs)
 
             # aiohttp only allows basic auth with their built in auth, so we
@@ -427,7 +434,7 @@ class Gen3Metadata:
             async with session.put(
                 url_with_params, json=metadata, headers=headers, ssl=_ssl
             ) as response:
-                raise_for_status_and_print_error(response)
+                response.raise_for_status()
                 response = await response.json()
 
         return response
@@ -445,7 +452,7 @@ class Gen3Metadata:
         url_with_params = append_query_params(url, **kwargs)
         logging.debug(f"hitting: {url_with_params}")
         response = requests.delete(url_with_params, auth=self._auth_provider)
-        raise_for_status_and_print_error(response)
+        response.raise_for_status()
 
         return response.json()
 
